All Classes and Interfaces
Class
Description
The
AbstractBytesDestination is a base abstract implementation of the
BytesDestination interface providing common functionality for
concrete real implementations.The
AbstractBytesReceiver is a base abstract implementation of the
BytesReceiver interface providing common functionality for concrete
real live implementations.The Class ConnectableAutomaton.
The
AbstractBytesTransmitter is a base abstract implementation of the
BytesTransmitter interface providing common functionality for
concrete real live implementations.The
AbstractDatagramsReceiver is a base abstract implementation of
the DatagramsReceiver interface providing common functionality for
concrete real live implementations.The
AbstractDatagramsTransmitter is a base abstract implementation of
the BytesTransmitter interface providing common functionality for
concrete real live implementations.Abstract implementation of the
BytesReceiver interface.Abstract implementation of the
DatagramsReceiver interface.Abstract implementation of the
BytesReceiver interface.Abstract implementation of the
DatagramsReceiver interface.The
AbstractShortsDestination is a base abstract implementation of
the ShortsDestination interface providing common functionality for
concrete real live implementations.The
AbstractShortsReceiver is a base abstract implementation of the
ShortsReceiver interface providing common functionality for concrete
real live implementations.The Class ConnectableAutomaton.
The
AbstractShortsTransmitter is a base abstract implementation of
the ShortsTransmitter interface providing common functionality for
concrete real live ShortsTransmitter and ShortsTransmitter (=
ShortsTransmitter) implementations.The
Availability interface defines methods to test availability of
data.The
AvailableInputStream decorates an InputStream with
time-out functionality using the InputStream.available() method.The
BidirectionalConnectionByteTransceiver defines the
DatagramTransceiver functionality set on top of a I/O connection (as
of the BidirectionalConnectionComponent.BidirectionalConnectionAutomaton).The
BidirectionalConnectionTransceiver defines the
DatagramTransceiver functionality set on top of a I/O connection (as
of the BidirectionalConnectionComponent.BidirectionalConnectionAutomaton).The Class BidirectionalStreamByteTransceiver.
A
BidirectionalStreamConnectionByteTransceiver is a
DatagramTransceiver connected through I/O streams with another
BidirectionalStreamConnectionByteTransceiver.The Class BidirectionalStreamConnectionByteTransceiverImpl.
A
BidirectionalStreamConnectionTransceiver is a
DatagramTransceiver connected through I/O streams with another
BidirectionalStreamConnectionTransceiver.The Class BidirectionalStreamConnectionTransceiverImpl.
The Class BidirectionalStreamTransceiver.
A
BijectiveOutputStream wraps an OutputStream and produces
output bytes by applying a BijectiveFunction on each byte to be
written before delegating the processed vale to the given
OutputStream.The
BlockingInputStream wraps an InputStream adding blocking
functionality, e.g. when trying to read, the read operation is blocked till
BlockingInputStream.available() returns a value greater than 0.A
BoundedInputStream decorates an InputStream and restricts
reading bytes from the InputStream decoratee up to a given total
number of bytes (bounds).The Class ByteArrayReceiver.
The Class ByteArraySource.
The
ByteDestination is used to receive bytes in a unified way.The
ByteReceiver is used to receive bytes in a unified way.The
BytesDestination is used to receive byte blocks (arrays) in a
unified way.(as
InputStream does not provide some useful *interface*)The
ByteSource is used to send bytes in a unified way.(as
OutputStream does not provide some useful *interface*)The Interface BytesReceiver.
The
BytesReceiverDecorator decorates a BytesDestination with
the additional methods of a BytesReceiver making it easy to use a
BytesDestination wherever a BytesReceiver is expected.The
BytesSource is used to send byte blocks (arrays) in a unified
way.A
BytesTransceiver combines the functionality of a
BytesTransmitter and of a BytesReceiver. e.g. for building
loopback devices.The Interface BytesTransmitter.
Combines the
ByteTransmitter and ByteReceiver functionality
in a single interface to be implemented by a single class so that
ByteTransmitter and ByteReceiver functionality can be
provided by a single instance.The
ByteTransmitter is used to transmit bytes in a unified way.The
ByteTransmitterDecorator decorates a BytesSource with the
additional methods of a BytesTransmitter making it easy to use a
BytesSource wherever a BytesTransmitter is expected.A
ClipboardInputStream provides the clipboard as InputStream.A
ClipboardOutputStream writes into the clipboard after
ClipboardOutputStream.flush() as well as ClipboardOutputStream.close() being called.The
ConnectionBytesReceiver defines the DatagramReceiver
functionality set on top of a connection (as of the
ConnectionComponent.ConnectionAutomaton) for data types "byte".The
ConnectionBytesTransceiver defines the
DatagramTransceiver functionality set on top of a connection (as of
the ConnectionComponent.ConnectionAutomaton) for data types "byte".The
ConnectionBytesTransmitter defines the
DatagramTransmitter functionality set on top of a connection (as of
the ConnectionComponent.ConnectionAutomaton) for data types "byte".The
ConnectionDatagramsReceiver defines the DatagramReceiver
functionality set on top of a connection (as of the
ConnectionComponent.ConnectionAutomaton).The
ConnectionDatagramsTransceiver defines the
DatagramTransceiver functionality set on top of a connection (as of
the ConnectionComponent.ConnectionAutomaton).The
ConnectionDatagramsTransmitter defines the
DatagramTransmitter functionality set on top of a connection (as of
the ConnectionComponent.ConnectionAutomaton).The
ConnectionShortsReceiver defines the DatagramReceiver
functionality set on top of a connection (as of the
ConnectionComponent.ConnectionAutomaton) for data types "short".The
ConnectionShortsTransceiver defines the
DatagramTransceiver functionality set on top of a connection (as of
the ConnectionComponent.ConnectionAutomaton) for data types "short".The
ConnectionShortsTransmitter defines the
DatagramTransmitter functionality set on top of a connection (as of
the ConnectionComponent.ConnectionAutomaton) for data types "short".The
DatagramDestination is used to receive datagrams in a unified
way.The
DatagramReceiver is used to receive datagrams in a unified way.The
DatagramsDestination is used to receive data blocks (arrays) in a
unified way.The
DatagramSource is used to send datagrams in a unified way.The Interface DatagramsReceiver.
The
DatagramsReceiverDecorator decorates a
DatagramsDestination with the additional methods of a
DatagramsReceiver making it easy to use a
DatagramsDestination wherever a DatagramsReceiver is
expected.The
DatagramsSource is used to send datagram blocks (arrays) in a
unified way.A
DatagramsTransceiver combines the functionality of a
DatagramsTransmitter and of a DatagramsReceiver. e.g. for
building loopback devices.The
DatagramsTransmitter is used to send datagram blocks (arrays) in
a unified way.Combines the
DatagramTransmitter and DatagramReceiver
functionality in a single interface to be implemented by a single class so
that DatagramTransmitter and DatagramReceiver functionality
can be provided by a single instance.The
DatagramTransmitter is used to send datagrams in a unified way.The
FileUtility provides Various file related utility functionality.The
FilterInputStream wraps an InputStream adding filtering
functionality of bytes to be skipped.A
HexOutputStream wraps an OutputStream printing out the
bytes written to the HexOutputStream as hexadecimal text to the
wrapped OutputStream.The Class InputStreamByteReceiver.
A
InputStreamConnectionByteReceiver is a DatagramReceiver
connected through I/O streams with a
OutputStreamConnectionDatagramsTransmitter.Implementation of the
InputStreamConnectionReceiver interface.A
InputStreamConnectionReceiver is a DatagramReceiver
connected through I/O streams with a
OutputStreamConnectionDatagramsTransmitter.Implementation of the
InputStreamConnectionReceiver interface.The Class InputStreamReceiver.
The
InputStreamTap decorates an InputStreamTap by tapping
(sniffing data from) an InputStream and besides returning the read
data writes it to the provided OutputStream.A
InverseInputStream wraps an InputStream and consumes input
bytes by applying a InverseFunction on each byte read from the
provided InputStream before passing back the processed byte to the
caller.Extends the
ResultAccessor interface with an I/O timeout mechanism.A
LineBreakOutputStream wraps an OutputStream for adding line
breaks after a given number of bytes being written.A
LoopbackBytesReceiver is a DatagramReceiver connected
directly within the same JVM with a LoopbackBytesTransmitter; a
"loopback" connection is used for establishing the connection which cannot be
accessed outside the JVM or the running machine.A
LoopbackBytesTransceiver is a DatagramTransceiver connected
directly within the same JVM with another LoopbackBytesTransceiver; a
"loopback" connection is used for establishing the connection which cannot be
accessed outside the JVM or the running machine.A
LoopbackBytesTransmitter is a DatagramTransmitter connected
directly within the same JVM with a LoopbackBytesReceiver; a
"loopback" connection is used for establishing the connection which cannot be
accessed outside the JVM or the running machine.A
LoopbackDatagramsReceiver is a DatagramReceiver connected
directly within the same JVM with a LoopbackDatagramsTransmitter; a
"loopback" connection is used for establishing the connection which cannot be
accessed outside the JVM or the running machine.A
LoopbackDatagramsTransceiver is a DatagramTransceiver
connected directly within the same JVM with another
LoopbackDatagramsTransceiver; a "loopback" connection is used for
establishing the connection which cannot be accessed outside the JVM or the
running machine.A
LoopbackDatagramsTransmitter is a DatagramTransmitter
connected directly within the same JVM with a
LoopbackDatagramsReceiver; a "loopback" connection is used for
establishing the connection which cannot be accessed outside the JVM or the
running machine.A
LoopbackShortsReceiver is a DatagramReceiver connected
directly within the same JVM with a LoopbackShortsTransmitter; a
"loopback" connection is used for establishing the connection which cannot be
accessed outside the JVM or the running machine.A
LoopbackShortsTransceiver is a DatagramTransceiver
connected directly within the same JVM with another
LoopbackShortsTransceiver; a "loopback" connection is used for
establishing the connection which cannot be accessed outside the JVM or the
running machine.A
LoopbackShortsTransmitter is a DatagramTransmitter
connected directly within the same JVM with a LoopbackBytesReceiver;
a "loopback" connection is used for establishing the connection which cannot
be accessed outside the JVM or the running machine.Provides an accessor for a maximum connections property.
Provides a builder method for a maximum connections property returning
the builder for applying multiple build operations.
Provides a mutator for a maximum connections property.
Provides a maximum connections property.
The Class OutputStreamBytesTransmitter.
A
OutputStreamComposite wraps multiple OutputStream instances
to which to dispatch any operation applied to the
OutputStreamComposite instance.A
OutputStreamConnectionBytesTransmitter is a
DatagramTransmitter connected through I/O streams with a
InputStreamConnectionReceiver.A
OutputStreamConnectionDatagramsTransmitter is a
DatagramTransmitter connected through I/O streams with a
InputStreamConnectionReceiver.A
OutputStreamConnectionShortsTransmitter is a
DatagramTransmitter connected through I/O streams with a
InputStreamConnectionReceiver.The Class OutputStreamDatagramsTransmitter.
The Class OutputStreamShortsTransmitter.
The Class PrefetchBidirectionalStreamByteTransceiver.
The Class PrefetchBidirectionalStreamConnectionByteTransceiver.
The Class PrefetchBidirectionalStreamConnectionTransceiver.
The Class PrefetchBidirectionalStreamTransceiver.
The Class PrefetchInputStreamByteReceiver.
Implementation of the
InputStreamConnectionReceiver interface.Implementation of the
InputStreamConnectionReceiver interface.The Class PrefetchInputStreamReceiver.
The Interface Receivable.
The
ReplaceInputStream replaces a give byte sequence with another
given bytes sequence.
The
ReplayInputStream wraps an InputStream adding
ReplayInputStream.mark(int), ReplayInputStream.markSupported() as well as ReplayInputStream.reset()
functionality, similar to the BufferedInputStream.A
RowReader reads a set of elements (a row) from an external source.A
RowWriter writes a set of elements (a row) to an external
destination.Makes the wrapped
Iterator serializable, else passing
Iterator instances would cause an NotSerializableException or
similar.Makes the wrapped
ListIterator serializable, else passing
ListIterator instances would cause an
NotSerializableException or similar.The
SerializableObjectInputStream extends an ordinary
ObjectInputStream to also resolve primitive types.The Class ShortArrayReceiver.
The Class ShortArraySource.
The
ShortDestination is used to receive shorts in a unified way.The
ShortReceiver is used to receive shot values in a unified way.The
ShortsDestination is used to receive short blocks (arrays) in a
unified way.The
ShortSource is used to send shorts in a unified way.The Interface ShortsReceiver.
The
ShortsReceiverDecorator decorates a ShortsDestination
with the additional methods of a ShortsReceiver making it easy to use
a ShortsDestination wherever a ShortsReceiver is expected.The
ShortsSource is used to send short blocks (arrays) in a unified
way.A
ShortsTransceiver combines the functionality of a
ShortsTransmitter and of a ShortsReceiver. e.g. for building
loopback devices.The
ShortsTransmitter is used to send short blocks (arrays) in a
unified way.Combines the
ShortTransmitter and ShortReceiver functionality
in a single interface to be implemented by a single class so that
ShortsTransmitter and ShortReceiver functionality can be
provided by a single instance.The Interface ShortsTransmitter.
The
ShortTransmitterDecorator decorates a ShortsSource with
the additional methods of a ShortsTransmitter making it easy to use a
ShortsSource wherever a ShortsTransmitter is expected.The
SkipAvailableInputStream decorates an InputStream with
skip timed functionality, e.g. skip all currently available bytes
(Skippable.skipAvailable()), all bytes available for a period of time
(SkipAvailableInputStream.skipAvailableWithin(long)) or skip all bytes available till a send
pause of a given time is detected (SkipAvailableInputStream.skipAvailableTillSilenceFor(long)
or Skippable.skipAvailableTillSilenceFor(long, long)).The
Skippable interface defines methods useful for omitting bytes
known to be unusable for the according operation.The
TimeoutInputStream decorates an InputStream with time-out
functionality using CompletableFuture functionality.Provides an accessor for an timeout input stream property.
Provides a mutator for an timeout input stream property.
Provides a mutator for an timeout input stream property.
Provides an timeout input stream property.
The Interface Transmittable.
The
TransmitterDecorator decorates a DatagramsSource with the
additional methods of a DatagramsTransmitter making it easy to use a
DatagramsSource wherever a DatagramsTransmitter is expected.Represents an
InputStream from a provided File: In case the
file points to a ZIP compressed file, then the uncompressed data of the
therein contained file with the same name excluding the ".zip" extension is
provided by the InputStream.Represents an
OutputStream to a provided File: In case the
file points to a ZIP compressed file, then a therein to be contained file
with the same name excluding the ".zip" extension is created by the
OutputStream.Utility class for some ZIP compression related issues.