Constant Field Values
Contents
org.refcodes.*
-
org.refcodes.io.AbstractBytesDestination Modifier and Type Constant Field Value public static final intDATAGRAM_QUEUE_SIZE1024 -
org.refcodes.io.AbstractDatagramsReceiver<DATA extends Serializable> Modifier and Type Constant Field Value public static final intDATAGRAM_QUEUE_SIZE1024 -
org.refcodes.io.AbstractShortsDestination Modifier and Type Constant Field Value public static final intDATAGRAM_QUEUE_SIZE1024