Module org.refcodes.io
module org.refcodes.io
-
Packages
ExportsPackageDescriptionThis artifact defines basic types handling communication between processes (across system boundaries), to be harnessed by complex and low level I/O, such as theInputStreamdecorator typesReplayInputStream,FilterInputStream,ClipboardInputStream,ZipFileInputStream,ReplaceInputStreamorTimeoutInputStreamalongsideAvailableInputStreamas well as theOutputStreamdecorator typesClipboardOutputStream,LineBreakOutputStreamorZipFileOutputStream.