Interface BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>
- Type Parameters:
INPUT- The type of the input connection to be used.OUTPUT- The type of the output connection to be used.
- All Superinterfaces:
Availability, BidirectionalConnectionComponent<INPUT,OUTPUT>, BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT, OUTPUT>, BidirectionalConnectionOpenable<INPUT, OUTPUT>, BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT, OUTPUT>, ByteDestination, ByteReceiver, BytesDestination, ByteSource, BytesReceiver, BytesSource, BytesTransceiver, BytesTransmitter, ByteTransceiver, ByteTransmitter, Closable, Closable.CloseAutomaton, ClosedAccessor, ConnectableComponent, ConnectableComponent.ConnectableAutomaton, ConnectionStatusAccessor, Flushable, Flushable, InputStreamAccessor, OpenedAccessor, OutputStreamAccessor, Receivable, Skippable, TimeoutInputStreamAccessor, Transmittable
- All Known Subinterfaces:
BidirectionalStreamConnectionByteTransceiver
- All Known Implementing Classes:
BidirectionalStreamConnectionByteTransceiverImpl, PrefetchBidirectionalStreamConnectionByteTransceiver
public interface BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>
extends BytesTransceiver, BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>
The
BidirectionalConnectionByteTransceiver defines the
DatagramTransceiver functionality set on top of a I/O connection (as
of the BidirectionalConnectionComponent.BidirectionalConnectionAutomaton).-
Nested Class Summary
Nested classes/interfaces inherited from interface BidirectionalConnectionComponent
BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT> Nested classes/interfaces inherited from interface BidirectionalConnectionOpenable
BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT> Nested classes/interfaces inherited from interface BytesReceiver
BytesReceiver.ReceiverInputStreamNested classes/interfaces inherited from interface BytesTransmitter
BytesTransmitter.TransmitterOutputStreamNested classes/interfaces inherited from interface Closable
Closable.CloseAutomaton, Closable.CloseBuilder<B>Nested classes/interfaces inherited from interface ClosedAccessor
ClosedAccessor.ClosedMutator, ClosedAccessor.ClosedPropertyNested classes/interfaces inherited from interface ConnectableComponent
ConnectableComponent.ConnectableAutomatonNested classes/interfaces inherited from interface ConnectionStatusAccessor
ConnectionStatusAccessor.ConnectionStatusMutator, ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface Flushable
Flushable.FlushBuilder<B>Nested classes/interfaces inherited from interface InputStreamAccessor
InputStreamAccessor.InputStreamBuilder<B>, InputStreamAccessor.InputStreamMutator, InputStreamAccessor.InputStreamPropertyNested classes/interfaces inherited from interface OpenedAccessor
OpenedAccessor.OpenedMutator, OpenedAccessor.OpenedPropertyNested classes/interfaces inherited from interface OutputStreamAccessor
OutputStreamAccessor.OutputStreamBuilder<B>, OutputStreamAccessor.OutputStreamMutator, OutputStreamAccessor.OutputStreamPropertyNested classes/interfaces inherited from interface TimeoutInputStreamAccessor
TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<B>, TimeoutInputStreamAccessor.TimeoutInputStreamMutator, TimeoutInputStreamAccessor.TimeoutInputStreamProperty -
Method Summary
Methods inherited from interface Availability
available, hasAvailableMethods inherited from interface BidirectionalConnectionOpenable
openMethods inherited from interface BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton
isOpenableMethods inherited from interface BytesDestination
receiveByte, receiveBytesMethods inherited from interface BytesReceiver
getInputStream, getInputStream, receiveAllBytes, receiveBytes, receiveBytesWithin, receiveBytesWithin, receiveByteWithin, skipMethods inherited from interface BytesSource
transmitByte, transmitBytesMethods inherited from interface BytesTransmitter
getOutputStream, transmitBytesMethods inherited from interface ByteTransmitter
flushMethods inherited from interface Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface Closable.CloseAutomaton
isClosableMethods inherited from interface ClosedAccessor
isClosedMethods inherited from interface ConnectionStatusAccessor
getConnectionStatus, isOpenedMethods inherited from interface Flushable
flushUnchecked, isFlushableMethods inherited from interface Skippable
available, skipAvailable, skipAvailableExcept, skipAvailableTill, skipAvailableTillSilenceFor, skipAvailableTillSilenceFor, skipAvailableWithin, skipAvailableWithin, skipAvailableWithin