Interface BidirectionalStreamConnectionTransceiver<DATA extends Serializable>

Type Parameters:
DATA - The type of the datagram to be operated with.
All Superinterfaces:
Availability, org.refcodes.component.BidirectionalConnectionComponent<InputStream,OutputStream>, org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<InputStream,OutputStream>, org.refcodes.component.BidirectionalConnectionOpenable<InputStream,OutputStream>, org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<InputStream,OutputStream>, BidirectionalConnectionTransceiver<DATA,InputStream,OutputStream>, org.refcodes.component.Closable, org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.ClosedAccessor, org.refcodes.component.ConnectableComponent, org.refcodes.component.ConnectableComponent.ConnectableAutomaton, org.refcodes.component.ConnectionStatusAccessor, DatagramDestination<DATA>, DatagramReceiver<DATA>, DatagramsDestination<DATA>, DatagramSource<DATA>, DatagramsReceiver<DATA>, DatagramsSource<DATA>, DatagramsTransceiver<DATA>, DatagramsTransmitter<DATA>, DatagramTransceiver<DATA>, DatagramTransmitter<DATA>, Flushable, org.refcodes.component.Flushable, org.refcodes.component.OpenedAccessor, Receivable, Transmittable
All Known Implementing Classes:
BidirectionalStreamConnectionTransceiverImpl, PrefetchBidirectionalStreamConnectionTransceiver

public interface BidirectionalStreamConnectionTransceiver<DATA extends Serializable> extends BidirectionalConnectionTransceiver<DATA,InputStream,OutputStream>
A BidirectionalStreamConnectionTransceiver is a DatagramTransceiver connected through I/O streams with another BidirectionalStreamConnectionTransceiver. A Socket or a ServerSocket may be used to retrieve the according I/O streams.