Interface ByteReceiver
- All Superinterfaces:
Availability, ByteDestination, Closable, Closable.CloseAutomaton, ClosedAccessor, ConnectableComponent, ConnectableComponent.ConnectableAutomaton, ConnectionStatusAccessor, OpenedAccessor, Receivable
- All Known Subinterfaces:
BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>, BidirectionalStreamConnectionByteTransceiver, BytesReceiver, BytesTransceiver, ByteTransceiver, ConnectionBytesReceiver<CON>, ConnectionBytesTransceiver<CON>, InputStreamConnectionByteReceiver
- All Known Implementing Classes:
AbstractBytesReceiver, AbstractInputStreamByteReceiver, AbstractPrefetchInputStreamByteReceiver, BidirectionalStreamByteTransceiver, BidirectionalStreamConnectionByteTransceiverImpl, ByteArrayReceiver, BytesReceiverDecorator, InputStreamByteReceiver, InputStreamConnectionByteReceiverImpl, LoopbackBytesReceiver, LoopbackBytesTransceiver, PrefetchBidirectionalStreamByteTransceiver, PrefetchBidirectionalStreamConnectionByteTransceiver, PrefetchInputStreamByteReceiver, PrefetchInputStreamConnectionByteReceiver
The
ByteReceiver is used to receive bytes in a unified way. The
ByteDestination.receiveByte() method provides the next available datagram from the
counterpart DatagramTransmitter; in case there is none available,
then this method halts until one is available or the ByteReceiver is
being shut down or the underlying connection is closed. The
Availability.available() method returns true in case a next datagram can be
fetched via the ByteDestination.receiveByte() method from the ByteReceiver
counterpart.-
Nested Class Summary
Nested classes/interfaces inherited from interface Closable
Closable.CloseAutomaton, Closable.CloseBuilder<B>Nested classes/interfaces inherited from interface ClosedAccessor
ClosedAccessor.ClosedMutator, ClosedAccessor.ClosedPropertyNested classes/interfaces inherited from interface ConnectableComponent
ConnectableComponent.ConnectableAutomatonNested classes/interfaces inherited from interface ConnectionStatusAccessor
ConnectionStatusAccessor.ConnectionStatusMutator, ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface OpenedAccessor
OpenedAccessor.OpenedMutator, OpenedAccessor.OpenedProperty -
Method Summary
Methods inherited from interface Availability
available, hasAvailableMethods inherited from interface ByteDestination
receiveByteMethods inherited from interface Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface Closable.CloseAutomaton
isClosableMethods inherited from interface ClosedAccessor
isClosedMethods inherited from interface ConnectionStatusAccessor
getConnectionStatus, isOpened