Interface ByteTransceiver

All Superinterfaces:
Availability, ByteDestination, ByteReceiver, ByteSource, ByteTransmitter, org.refcodes.component.Closable, org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.ClosedAccessor, org.refcodes.component.ConnectableComponent, org.refcodes.component.ConnectableComponent.ConnectableAutomaton, org.refcodes.component.ConnectionStatusAccessor, Flushable, org.refcodes.component.Flushable, org.refcodes.component.OpenedAccessor, Receivable, Transmittable
All Known Subinterfaces:
BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>, BidirectionalStreamConnectionByteTransceiver, BytesTransceiver, ConnectionBytesTransceiver<CON>
All Known Implementing Classes:
BidirectionalStreamByteTransceiver, BidirectionalStreamConnectionByteTransceiverImpl, LoopbackBytesTransceiver, PrefetchBidirectionalStreamByteTransceiver, PrefetchBidirectionalStreamConnectionByteTransceiver

public interface ByteTransceiver extends ByteTransmitter, ByteReceiver
Combines the ByteTransmitter and ByteReceiver functionality in a single interface to be implemented by a single class so that ByteTransmitter and ByteReceiver functionality can be provided by a single instance.