Interface InputStreamConnectionReceiver<DATA extends Serializable>

Type Parameters:
DATA - The type of the datagram to be operated with.
All Superinterfaces:
Availability, org.refcodes.component.Closable, org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.ClosedAccessor, org.refcodes.component.ConnectableComponent, org.refcodes.component.ConnectableComponent.ConnectableAutomaton, org.refcodes.component.ConnectionComponent<InputStream>, org.refcodes.component.ConnectionComponent.ConnectionAutomaton<InputStream>, ConnectionDatagramsReceiver<DATA,InputStream>, org.refcodes.component.ConnectionOpenable<InputStream>, org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<InputStream>, org.refcodes.component.ConnectionStatusAccessor, DatagramDestination<DATA>, DatagramReceiver<DATA>, DatagramsDestination<DATA>, DatagramsReceiver<DATA>, org.refcodes.component.OpenedAccessor, Receivable
All Known Implementing Classes:
InputStreamConnectionReceiverImpl, PrefetchInputStreamConnectionReceiver

public interface InputStreamConnectionReceiver<DATA extends Serializable> extends ConnectionDatagramsReceiver<DATA,InputStream>
A InputStreamConnectionReceiver is a DatagramReceiver connected through I/O streams with a OutputStreamConnectionDatagramsTransmitter. A Socket or a ServerSocket may be used to retrieve the according I/O streams.