Class InputStreamString
java.lang.Object
org.refcodes.io.InputStreamString
-
Constructor Summary
ConstructorsConstructorDescriptionInputStreamString(InputStream aInputStream) InputStreamString(InputStream aInputStream, String aEncoding) Constructs anInputStreamStringfrom the providedInputStreamand the provided encoding.InputStreamString(InputStream aInputStream, Charset aCharset) Constructs anInputStreamStringfrom the providedInputStreamand the provided encoding. -
Method Summary
Modifier and TypeMethodDescriptiontoString()String[]The method splits the resulting string (as oftoString()) into an array of separate lines as of the CR and/or LF occurrences in the string.
-
Constructor Details
-
InputStreamString
Constructs anInputStreamStringfrom the providedInputStreamand the provided encoding.- Parameters:
aInputStream- TheInputStreamfrom which to create aString.aCharset- TheCharsetto use when interpreting theInputStream.
-
InputStreamString
- Parameters:
aInputStream- TheInputStreamfrom which to create aString.
-
InputStreamString
Constructs anInputStreamStringfrom the providedInputStreamand the provided encoding.- Parameters:
aInputStream- TheInputStreamfrom which to create aString.aEncoding- The encoding to use when interpreting theInputStream.
-
-
Method Details
-
toString
-
toStrings
The method splits the resulting string (as oftoString()) into an array of separate lines as of the CR and/or LF occurrences in the string.- Returns:
- The according resulting
Stringarray
-