- java.lang.Object
-
- org.refcodes.component.AbstractConnectableAutomaton
-
- org.refcodes.io.AbstractShortsTransmitter
-
- org.refcodes.io.OutputStreamConnectionShortsTransmitter
-
- All Implemented Interfaces:
Flushable,org.refcodes.component.Closable,org.refcodes.component.Closable.CloseAutomaton,org.refcodes.component.ClosedAccessor,org.refcodes.component.ConnectableComponent,org.refcodes.component.ConnectableComponent.ConnectableAutomaton,org.refcodes.component.ConnectionComponent<OutputStream>,org.refcodes.component.ConnectionComponent.ConnectionAutomaton<OutputStream>,org.refcodes.component.ConnectionOpenable<OutputStream>,org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<OutputStream>,org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.Flushable,org.refcodes.component.OpenedAccessor,ConnectionShortsTransmitter<OutputStream>,ShortSource,ShortsSource,ShortsTransmitter,ShortTransmitter,Transmittable
public class OutputStreamConnectionShortsTransmitter extends AbstractShortsTransmitter implements ConnectionShortsTransmitter<OutputStream>
AOutputStreamConnectionShortsTransmitteris aDatagramTransmitterconnected through I/O streams with aInputStreamConnectionReceiver. ASocketor aServerSocketmay be used to retrieve the according I/O streams.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>
-
Nested classes/interfaces inherited from interface org.refcodes.component.ClosedAccessor
org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedProperty
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectableComponent
org.refcodes.component.ConnectableComponent.ConnectableAutomaton
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionComponent
org.refcodes.component.ConnectionComponent.ConnectionAutomaton<CON extends Object>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON extends Object,B extends org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionOpenable
org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<CON extends Object>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON extends Object,B extends org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B>>
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusProperty
-
-
Constructor Summary
Constructors Constructor Description OutputStreamConnectionShortsTransmitter()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidclose()voidflush()booleanisOpenable(OutputStream aOutputStream)voidopen(OutputStream aOutputStream)voidtransmitShort(short aShort)Writes (sends) a short.-
Methods inherited from class org.refcodes.component.AbstractConnectableAutomaton
getConnectionStatus, isClosable, isClosed, isOpenable, isOpened, open, setConnectionStatus
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.component.Closable
closeIn, closeQuietly, closeUnchecked
-
Methods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpened
-
Methods inherited from interface org.refcodes.io.ShortsSource
transmitAllShorts
-
Methods inherited from interface org.refcodes.io.ShortsTransmitter
transmitShorts
-
-
-
-
Method Detail
-
open
public void open(OutputStream aOutputStream) throws IOException
- Specified by:
openin interfaceorg.refcodes.component.ConnectionOpenable<OutputStream>- Throws:
IOException
-
isOpenable
public boolean isOpenable(OutputStream aOutputStream)
- Specified by:
isOpenablein interfaceorg.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<OutputStream>
-
flush
public void flush() throws IOException- Specified by:
flushin interfaceFlushable- Specified by:
flushin interfaceorg.refcodes.component.Flushable- Specified by:
flushin interfaceShortTransmitter- Throws:
IOException
-
close
public void close() throws IOException- Specified by:
closein interfaceorg.refcodes.component.Closable- Overrides:
closein classorg.refcodes.component.AbstractConnectableAutomaton- Throws:
IOException
-
transmitShort
public void transmitShort(short aShort) throws IOExceptionWrites (sends) a short.- Specified by:
transmitShortin interfaceShortSource- Specified by:
transmitShortin interfaceShortsSource- Parameters:
aShort- The short to be pushed.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
-