Interface RowReader<T>

All Superinterfaces:
AutoCloseable

public interface RowReader<T>
extends AutoCloseable
A RowReader reads a set of elements (a row) elements for an external source.
  • Method Summary

    Modifier and Type Method Description
    boolean hasNext()
    Determines whether a next element can be read.
    T readNext()
    Reads the next element.

    Methods inherited from interface java.lang.AutoCloseable

    close
  • Method Details

    • hasNext

      boolean hasNext()
      Determines whether a next element can be read.
      Returns:
      True in case there is a next element, false if not.
    • readNext

      T readNext() throws IOException
      Reads the next element.
      Returns:
      The next element being read.
      Throws:
      IOException - thrown in case there was an I/O related problem.
      NoSuchElementException - thrown in case there is none next element to be read (check with hasNext() if there is actually a next element which can be read).