Class SerializableIterator<T>

java.lang.Object
org.refcodes.io.SerializableIterator<T>
Type Parameters:
T - The type of the instances managed by the Iterator.
All Implemented Interfaces:
Serializable, Iterator<T>

public class SerializableIterator<T> extends Object implements Iterator<T>, Serializable
Makes the wrapped Iterator serializable, else passing Iterator instances would cause an NotSerializableException or similar.
See Also: