- All Known Subinterfaces:
ConnectionShortsReceiver<CON>,ConnectionShortsTransceiver<CON>,ShortReceiver,ShortsDestination,ShortsReceiver,ShortsTransceiver,ShortTransceiver
- All Known Implementing Classes:
AbstractShortsDestination,AbstractShortsReceiver,LoopbackShortsReceiver,LoopbackShortsTransceiver,ShortArrayReceiver,ShortsReceiverDecorator
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
The
ShortDestination is used to receive shorts in a unified way. The
receiveShort() method provides the next available short from the
counterpart DatagramTransmitter; in case there is none available,
then this method halts until one is available.-
Method Summary
Modifier and TypeMethodDescriptionshortReads (receives) the next short available, in case none short is available, then this method blocks until one is available.
-
Method Details
-
receiveShort
Reads (receives) the next short available, in case none short is available, then this method blocks until one is available.- Returns:
- The next short sent from the
ShortsTransmittercounterpart. - Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.EOFException- Signals that an end of file or end of stream has been reached unexpectedly during input.
-