- All Superinterfaces:
ShortSource
- All Known Subinterfaces:
ConnectionShortsTransceiver<CON>,ConnectionShortsTransmitter<CON>,ShortsTransceiver,ShortsTransmitter
- All Known Implementing Classes:
AbstractShortsTransmitter,LoopbackShortsTransceiver,LoopbackShortsTransmitter,OutputStreamConnectionShortsTransmitter,OutputStreamShortsTransmitter,ShortArraySource,ShortTransmitterDecorator
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
The
ShortsSource is used to send short blocks (arrays) in a unified
way.-
Method Summary
Modifier and TypeMethodDescriptiondefault voidtransmitAllShorts(short[] aShorts) Writes (sends) a short block.default voidtransmitShort(short aShort) Writes (sends) a short.voidtransmitShorts(short[] aShorts, int aOffset, int aLength) Writes (sends) a short block.
-
Method Details
-
transmitShort
Writes (sends) a short.- Specified by:
transmitShortin interfaceShortSource- Parameters:
aShort- The short to be pushed.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
transmitAllShorts
Writes (sends) a short block.- Parameters:
aShorts- The short to be pushed.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
transmitShorts
Writes (sends) a short block.- Parameters:
aShorts- The short to be pushed.aOffset- The offset from which to take the data.aLength- The number of elements to push starting at the given offset.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-