Interface TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<B extends TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<?>>
- Type Parameters:
B- The builder which implements theTimeoutInputStreamAccessor.TimeoutInputStreamBuilder.
- Enclosing interface:
TimeoutInputStreamAccessor
public static interface TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<B extends TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<?>>
Provides a mutator for an timeout input stream property.
-
Method Summary
Modifier and TypeMethodDescriptionwithInputStream(TimeoutInputStream aTimeoutInputStream) Sets the timeout input stream to use and returns this builder as of the Builder-Pattern.
-
Method Details
-
withInputStream
Sets the timeout input stream to use and returns this builder as of the Builder-Pattern.- Parameters:
aTimeoutInputStream- The timeout input stream to be stored by the input stream property.- Returns:
- This
TimeoutInputStreamAccessor.TimeoutInputStreamBuilderinstance to continue configuration.
-