Interface TimeoutInputStreamAccessor.TimeoutInputStreamMutator
- All Known Subinterfaces:
TimeoutInputStreamAccessor.TimeoutInputStreamProperty
- Enclosing interface:
TimeoutInputStreamAccessor
public static interface TimeoutInputStreamAccessor.TimeoutInputStreamMutator
Provides a mutator for an timeout input stream property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetInputStream(TimeoutInputStream aTimeoutInputStream) Sets the timeout input stream for the timeout input stream property.
-
Method Details
-
setInputStream
Sets the timeout input stream for the timeout input stream property.- Parameters:
aTimeoutInputStream- The timeout input stream to be stored by the input stream property.
-