Module org.refcodes.io
Package org.refcodes.io
Interface TimeoutInputStreamAccessor.TimeoutInputStreamProperty
- All Superinterfaces:
org.refcodes.mixin.InputStreamAccessor,TimeoutInputStreamAccessor,TimeoutInputStreamAccessor.TimeoutInputStreamMutator
- Enclosing interface:
- TimeoutInputStreamAccessor
public static interface TimeoutInputStreamAccessor.TimeoutInputStreamProperty
extends TimeoutInputStreamAccessor, TimeoutInputStreamAccessor.TimeoutInputStreamMutator
Provides an timeout input stream property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.InputStreamAccessor
org.refcodes.mixin.InputStreamAccessor.InputStreamBuilder<B extends org.refcodes.mixin.InputStreamAccessor.InputStreamBuilder<?>>, org.refcodes.mixin.InputStreamAccessor.InputStreamMutator, org.refcodes.mixin.InputStreamAccessor.InputStreamPropertyNested classes/interfaces inherited from interface org.refcodes.io.TimeoutInputStreamAccessor
TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<B extends TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<?>>, TimeoutInputStreamAccessor.TimeoutInputStreamMutator, TimeoutInputStreamAccessor.TimeoutInputStreamProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault TimeoutInputStreamletTimeoutInputStream(TimeoutInputStream aTimeoutInputStream) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTimeoutInputStream(setter) as ofTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)and returns the very same value (getter).Methods inherited from interface org.refcodes.mixin.InputStreamAccessor
getInputStreamMethods inherited from interface org.refcodes.io.TimeoutInputStreamAccessor
getInputStreamMethods inherited from interface org.refcodes.io.TimeoutInputStreamAccessor.TimeoutInputStreamMutator
setInputStream
-
Method Details
-
letTimeoutInputStream
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTimeoutInputStream(setter) as ofTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)and returns the very same value (getter).- Parameters:
aTimeoutInputStream- TheTimeoutInputStreamto set (viaTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-