Class ZipFileInputStream
java.lang.Object
java.io.InputStream
java.io.FilterInputStream
java.io.BufferedInputStream
org.refcodes.io.ZipFileInputStream
- All Implemented Interfaces:
Closeable, AutoCloseable
Represents an
InputStream from a provided File: In case the
file points to a ZIP compressed file, then the uncompressed data of the
therein contained file with the same name excluding the ".zip" extension is
provided by the InputStream.-
Field Summary
Fields inherited from class FilterInputStream
in -
Constructor Summary
ConstructorsConstructorDescriptionZipFileInputStream(File aFile) Instantiates a new zip file input stream impl.ZipFileInputStream(File parent, String child) Instantiates a new zip file input stream impl.ZipFileInputStream(String pathname) Instantiates a new zip file input stream impl.ZipFileInputStream(String parent, String child) Instantiates a new zip file input stream impl.ZipFileInputStream(URI uri) Instantiates a new zip file input stream impl. -
Method Summary
Methods inherited from class BufferedInputStream
available, close, mark, markSupported, read, read, reset, skip, transferToMethods inherited from class FilterInputStream
readMethods inherited from class InputStream
nullInputStream, readAllBytes, readNBytes, readNBytes, skipNBytes
-
Constructor Details
-
ZipFileInputStream
Instantiates a new zip file input stream impl.- Parameters:
parent- the parentchild- the child- Throws:
ZipException- the zip exceptionFileNotFoundException- the file not found exceptionIOException- Signals that an I/O exception has occurred.
-
ZipFileInputStream
Instantiates a new zip file input stream impl.- Parameters:
parent- the parentchild- the child- Throws:
ZipException- the zip exceptionFileNotFoundException- the file not found exceptionIOException- Signals that an I/O exception has occurred.
-
ZipFileInputStream
Instantiates a new zip file input stream impl.- Parameters:
pathname- the pathname- Throws:
ZipException- the zip exceptionFileNotFoundException- the file not found exceptionIOException- Signals that an I/O exception has occurred.
-
ZipFileInputStream
Instantiates a new zip file input stream impl.- Parameters:
uri- the uri- Throws:
ZipException- the zip exceptionFileNotFoundException- the file not found exceptionIOException- Signals that an I/O exception has occurred.
-
ZipFileInputStream
Instantiates a new zip file input stream impl.- Parameters:
aFile- the file- Throws:
ZipException- the zip exceptionFileNotFoundException- the file not found exceptionIOException- Signals that an I/O exception has occurred.
-