Uses of Class
org.refcodes.io.AbstractBytesDestination
-
Uses of AbstractBytesDestination in org.refcodes.io
Subclasses of AbstractBytesDestination in org.refcodes.ioModifier and TypeClassDescriptionclassTheAbstractBytesReceiveris a base abstract implementation of theBytesReceiverinterface providing common functionality for concrete real live implementations.classAbstract implementation of theBytesReceiverinterface.classThe Class ByteArrayReceiver.classTheBytesReceiverDecoratordecorates aBytesDestinationwith the additional methods of aBytesReceivermaking it easy to use aBytesDestinationwherever aBytesReceiveris expected.classALoopbackBytesReceiveris aDatagramReceiverconnected directly within the same JVM with aLoopbackBytesTransmitter; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classALoopbackBytesTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackBytesTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classThe Class PrefetchBidirectionalStreamConnectionByteTransceiver.classImplementation of theInputStreamConnectionReceiverinterface.