Uses of Interface
org.refcodes.io.ByteDestination
-
Uses of ByteDestination in org.refcodes.io
Subinterfaces of ByteDestination in org.refcodes.ioModifier and TypeInterfaceDescriptioninterfaceBidirectionalConnectionByteTransceiver<INPUT,OUTPUT> TheBidirectionalConnectionByteTransceiverdefines theDatagramTransceiverfunctionality set on top of a I/O connection (as of theBidirectionalConnectionComponent.BidirectionalConnectionAutomaton).interfaceABidirectionalStreamConnectionByteTransceiveris aDatagramTransceiverconnected through I/O streams with anotherBidirectionalStreamConnectionByteTransceiver.interfaceTheByteReceiveris used to receive bytes in a unified way.interfaceTheBytesDestinationis used to receive byte blocks (arrays) in a unified way.interfaceThe Interface BytesReceiver.interfaceABytesTransceivercombines the functionality of aBytesTransmitterand of aBytesReceiver. e.g. for building loopback devices.interfaceCombines theByteTransmitterandByteReceiverfunctionality in a single interface to be implemented by a single class so thatByteTransmitterandByteReceiverfunctionality can be provided by a single instance.interfaceTheConnectionBytesReceiverdefines theDatagramReceiverfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "byte".interfaceTheConnectionBytesTransceiverdefines theDatagramTransceiverfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "byte".interfaceAInputStreamConnectionByteReceiveris aDatagramReceiverconnected through I/O streams with aOutputStreamConnectionDatagramsTransmitter.Classes in org.refcodes.io that implement ByteDestinationModifier and TypeClassDescriptionclassTheAbstractBytesDestinationis a base abstract implementation of theBytesDestinationinterface providing common functionality for concrete real implementations.classTheAbstractBytesReceiveris a base abstract implementation of theBytesReceiverinterface providing common functionality for concrete real live implementations.classAbstract implementation of theBytesReceiverinterface.classAbstract implementation of theBytesReceiverinterface.classThe Class BidirectionalStreamByteTransceiver.classThe Class BidirectionalStreamConnectionByteTransceiverImpl.classThe Class ByteArrayReceiver.classTheBytesReceiverDecoratordecorates aBytesDestinationwith the additional methods of aBytesReceivermaking it easy to use aBytesDestinationwherever aBytesReceiveris expected.classThe Class InputStreamByteReceiver.classImplementation of theInputStreamConnectionReceiverinterface.classALoopbackBytesReceiveris aDatagramReceiverconnected directly within the same JVM with aLoopbackBytesTransmitter; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classALoopbackBytesTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackBytesTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classThe Class PrefetchBidirectionalStreamByteTransceiver.classThe Class PrefetchBidirectionalStreamConnectionByteTransceiver.classThe Class PrefetchInputStreamByteReceiver.classImplementation of theInputStreamConnectionReceiverinterface.