Uses of Interface
org.refcodes.io.ByteSource
-
Uses of ByteSource in org.refcodes.io
Subinterfaces of ByteSource in org.refcodes.ioModifier and TypeInterfaceDescriptioninterfaceBidirectionalConnectionByteTransceiver<INPUT,OUTPUT> TheBidirectionalConnectionByteTransceiverdefines theDatagramTransceiverfunctionality set on top of a I/O connection (as of theBidirectionalConnectionComponent.BidirectionalConnectionAutomaton).interfaceABidirectionalStreamConnectionByteTransceiveris aDatagramTransceiverconnected through I/O streams with anotherBidirectionalStreamConnectionByteTransceiver.interfaceTheBytesSourceis used to send byte blocks (arrays) in a unified way.interfaceABytesTransceivercombines the functionality of aBytesTransmitterand of aBytesReceiver. e.g. for building loopback devices.interfaceThe Interface BytesTransmitter.interfaceCombines theByteTransmitterandByteReceiverfunctionality in a single interface to be implemented by a single class so thatByteTransmitterandByteReceiverfunctionality can be provided by a single instance.interfaceTheByteTransmitteris used to transmit bytes in a unified way.interfaceTheConnectionBytesTransceiverdefines theDatagramTransceiverfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "byte".interfaceTheConnectionBytesTransmitterdefines theDatagramTransmitterfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "byte".Classes in org.refcodes.io that implement ByteSourceModifier and TypeClassDescriptionclassTheAbstractBytesTransmitteris a base abstract implementation of theBytesTransmitterinterface providing common functionality for concrete real live implementations.classThe Class BidirectionalStreamByteTransceiver.classThe Class BidirectionalStreamConnectionByteTransceiverImpl.classThe Class ByteArraySource.classTheByteTransmitterDecoratordecorates aBytesSourcewith the additional methods of aBytesTransmittermaking it easy to use aBytesSourcewherever aBytesTransmitteris expected.classALoopbackBytesTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackBytesTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classALoopbackBytesTransmitteris aDatagramTransmitterconnected directly within the same JVM with aLoopbackBytesReceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classThe Class OutputStreamBytesTransmitter.classAOutputStreamConnectionBytesTransmitteris aDatagramTransmitterconnected through I/O streams with aInputStreamConnectionReceiver.classThe Class PrefetchBidirectionalStreamByteTransceiver.classThe Class PrefetchBidirectionalStreamConnectionByteTransceiver.