Uses of Class
org.refcodes.io.LoopbackBytesReceiver
-
Uses of LoopbackBytesReceiver in org.refcodes.io
Classes in org.refcodes.io that implement interfaces with type arguments of type LoopbackBytesReceiverModifier and TypeClassDescriptionclassALoopbackBytesTransmitteris aDatagramTransmitterconnected directly within the same JVM with aLoopbackBytesReceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.Methods in org.refcodes.io with parameters of type LoopbackBytesReceiverModifier and TypeMethodDescriptionbooleanLoopbackBytesTransmitter.isOpenable(LoopbackBytesReceiver aLoopbackReceiver) voidLoopbackBytesTransmitter.open(LoopbackBytesReceiver aLoopbackReceiver)