Uses of Class
org.refcodes.io.LoopbackBytesTransceiver
-
Uses of LoopbackBytesTransceiver in org.refcodes.io
Classes in org.refcodes.io that implement interfaces with type arguments of type LoopbackBytesTransceiverModifier and TypeClassDescriptionclassALoopbackBytesTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackBytesTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.Methods in org.refcodes.io with parameters of type LoopbackBytesTransceiverModifier and TypeMethodDescriptionbooleanLoopbackBytesTransceiver.isOpenable(LoopbackBytesTransceiver aLoopbackTransceiver) voidLoopbackBytesTransceiver.open(LoopbackBytesTransceiver aLoopbackTransceiver)