Uses of Class
org.refcodes.io.LoopbackBytesTransmitter
-
Uses of LoopbackBytesTransmitter in org.refcodes.io
Classes in org.refcodes.io that implement interfaces with type arguments of type LoopbackBytesTransmitterModifier and TypeClassDescriptionclassALoopbackBytesReceiveris aDatagramReceiverconnected directly within the same JVM with aLoopbackBytesTransmitter; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.Methods in org.refcodes.io with parameters of type LoopbackBytesTransmitterModifier and TypeMethodDescriptionbooleanLoopbackBytesReceiver.isOpenable(LoopbackBytesTransmitter aLoopbackSender) voidLoopbackBytesReceiver.open(LoopbackBytesTransmitter aLoopbackSender)