Uses of Interface
org.refcodes.io.ShortSource
-
Uses of ShortSource in org.refcodes.io
Subinterfaces of ShortSource in org.refcodes.ioModifier and TypeInterfaceDescriptioninterfaceTheConnectionShortsTransceiverdefines theDatagramTransceiverfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "short".interfaceTheConnectionShortsTransmitterdefines theDatagramTransmitterfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "short".interfaceTheShortsSourceis used to send short blocks (arrays) in a unified way.interfaceAShortsTransceivercombines the functionality of aShortsTransmitterand of aShortsReceiver. e.g. for building loopback devices.interfaceTheShortsTransmitteris used to send short blocks (arrays) in a unified way.interfaceCombines theShortTransmitterandShortReceiverfunctionality in a single interface to be implemented by a single class so thatShortsTransmitterandShortReceiverfunctionality can be provided by a single instance.interfaceThe Interface ShortsTransmitter.Classes in org.refcodes.io that implement ShortSourceModifier and TypeClassDescriptionclassTheAbstractShortsTransmitteris a base abstract implementation of theShortsTransmitterinterface providing common functionality for concrete real liveShortsTransmitterandShortsTransmitter(=ShortsTransmitter) implementations.classALoopbackShortsTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackShortsTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classALoopbackShortsTransmitteris aDatagramTransmitterconnected directly within the same JVM with aLoopbackBytesReceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classAOutputStreamConnectionShortsTransmitteris aDatagramTransmitterconnected through I/O streams with aInputStreamConnectionReceiver.classThe Class OutputStreamShortsTransmitter.classThe Class ShortArraySource.classTheShortTransmitterDecoratordecorates aShortsSourcewith the additional methods of aShortsTransmittermaking it easy to use aShortsSourcewherever aShortsTransmitteris expected.