Uses of Class
org.refcodes.io.TimeoutInputStream
-
Uses of TimeoutInputStream in org.refcodes.io
Subclasses of TimeoutInputStream in org.refcodes.ioModifier and TypeClassDescriptionclassTheAvailableInputStreamdecorates anInputStreamwith time-out functionality using theInputStream.available()method.Methods in org.refcodes.io that return TimeoutInputStreamModifier and TypeMethodDescriptiondefault TimeoutInputStreamBytesReceiver.getInputStream(long aTimeoutMillis) Retrieves theInputStreamas provided byBytesReceiver.getInputStream()wrapped in aTimeoutInputStreamor an implementation depended implementation of aTimeoutInputStream.TimeoutInputStreamAccessor.getInputStream(long aTimeoutMillis) Retrieves the timeout input stream from the timeout input stream property.default TimeoutInputStreamTimeoutInputStreamAccessor.TimeoutInputStreamProperty.letTimeoutInputStream(TimeoutInputStream aTimeoutInputStream) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTimeoutInputStream(setter) as ofTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)and returns the very same value (getter).Methods in org.refcodes.io with parameters of type TimeoutInputStreamModifier and TypeMethodDescriptiondefault TimeoutInputStreamTimeoutInputStreamAccessor.TimeoutInputStreamProperty.letTimeoutInputStream(TimeoutInputStream aTimeoutInputStream) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTimeoutInputStream(setter) as ofTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)and returns the very same value (getter).voidTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream aTimeoutInputStream) Sets the timeout input stream for the timeout input stream property.TimeoutInputStreamAccessor.TimeoutInputStreamBuilder.withInputStream(TimeoutInputStream aTimeoutInputStream) Sets the timeout input stream to use and returns this builder as of the Builder-Pattern.