public interface InputStreamStringBuilder extends InputStreamAccessor.InputStreamProperty, InputStreamAccessor.InputStreamBuilder<InputStreamStringBuilder>, org.refcodes.mixin.EncodingAccessor.EncodingProperty, org.refcodes.mixin.EncodingAccessor.EncodingBuilder<InputStreamStringBuilder>
InputStreamStringBuilder constructs String instances from
InputStream instances. Either use
InputStreamAccessor.InputStreamMutator.setInputStream(InputStream) (withInputStream(InputStream))
followed by a Object.toString() method (not thread safe) or directly
call toString(InputStream) (thread safe). You may specify an
encoding to be used such as UTF-8 by either setting the encoding attribute
with EncodingAccessor.EncodingMutator.setEncoding(String) (withEncoding(String)) or by
passing the encoding to the conversion method as of toString(String)
which overrules the encoding attribute.InputStreamAccessor.InputStreamBuilder<B extends InputStreamAccessor.InputStreamBuilder<B>>, InputStreamAccessor.InputStreamMutator, InputStreamAccessor.InputStreamPropertyorg.refcodes.mixin.EncodingAccessor.EncodingBuilder<B extends org.refcodes.mixin.EncodingAccessor.EncodingBuilder<B>>, org.refcodes.mixin.EncodingAccessor.EncodingMutator, org.refcodes.mixin.EncodingAccessor.EncodingProperty| Modifier and Type | Method and Description |
|---|---|
default String |
toString(InputStream aInputStream)
The
String being build by the builder upon the settings of the
attributes. |
String |
toString(InputStream aInputStream,
String aEncoding)
The
String being build by the builder upon the settings of the
attributes. |
String |
toString(String aEncoding)
The
Strings being build by the builder upon the settings of the
attributes. |
default String[] |
toStrings()
The
Strings being build by the builder upon the settings of the
attributes. |
default String[] |
toStrings(InputStream aInputStream)
The
Strings being build by the builder upon the settings of the
attributes. |
default String[] |
toStrings(InputStream aInputStream,
String aEncoding)
The
Strings being build by the builder upon the settings of the
attributes. |
default String[] |
toStrings(String aEncoding)
The
Strings being build by the builder upon the settings of the
attributes. |
default InputStreamStringBuilder |
withEncoding(String aEncoding) |
default InputStreamStringBuilder |
withInputStream(InputStream aInputStream)
Sets the
InputStream for the Input-Stream property. |
getInputStreamsetInputStreamdefault InputStreamStringBuilder withEncoding(String aEncoding)
withEncoding in interface org.refcodes.mixin.EncodingAccessor.EncodingBuilder<InputStreamStringBuilder>default InputStreamStringBuilder withInputStream(InputStream aInputStream)
InputStreamAccessor.InputStreamBuilderInputStream for the Input-Stream property.withInputStream in interface InputStreamAccessor.InputStreamBuilder<InputStreamStringBuilder>aInputStream - The InputStream to be stored by the
Input-Stream property.default String toString(InputStream aInputStream) throws IOException
String being build by the builder upon the settings of the
attributes.aInputStream - The InputStream which to convert into a
String.StringIOException - thrown in case accessing the InputStream
caused faults.default String[] toStrings(InputStream aInputStream) throws IOException
Strings being build by the builder upon the settings of the
attributes.aInputStream - The InputStream which to convert into a
String array.String arrayIOException - thrown in case accessing the InputStream
caused faults.default String[] toStrings() throws IOException
Strings being build by the builder upon the settings of the
attributes.String arrayIOException - thrown in case accessing the InputStream
caused faults.String toString(InputStream aInputStream, String aEncoding) throws IOException
String being build by the builder upon the settings of the
attributes.aInputStream - The InputStream which to convert into a
String.aEncoding - The text encoding to be used.StringIOException - thrown in case accessing the InputStream
caused faults.default String[] toStrings(InputStream aInputStream, String aEncoding) throws IOException
Strings being build by the builder upon the settings of the
attributes.aInputStream - The InputStream which to convert into a
String array.aEncoding - The text encoding to be used.String arrayIOException - thrown in case accessing the InputStream
caused faults.default String[] toStrings(String aEncoding) throws IOException
Strings being build by the builder upon the settings of the
attributes.aEncoding - The text encoding to be used.String arrayIOException - thrown in case accessing the InputStream
caused faults.String toString(String aEncoding) throws IOException
Strings being build by the builder upon the settings of the
attributes.aEncoding - The text encoding to be used.String arrayIOException - thrown in case accessing the InputStream
caused faults.Copyright © 2017. All rights reserved.