DATA - The type of the datagram to be operated with.public class PrefetchInputStreamConnectionReceiverImpl<DATA extends Serializable> extends AbstractPrefetchInputStreamReceiver<DATA> implements InputStreamConnectionReceiver<DATA>
InputStreamConnectionReceiver interface.org.refcodes.component.ConnectableComponent.ConnectableAutomatonorg.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedPropertyorg.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedPropertyorg.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyorg.refcodes.component.ConnectionComponent.ConnectionAutomaton<CON>, org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B extends org.refcodes.component.ConnectionComponent.ConnectionComponentBuilder<CON,B>>org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<CON>, org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B extends org.refcodes.component.ConnectionOpenable.ConnectionOpenBuilder<CON,B>>DATAGRAM_QUEUE_SIZE| Constructor and Description |
|---|
PrefetchInputStreamConnectionReceiverImpl()
Instantiates a new prefetch input stream connection receiver impl.
|
PrefetchInputStreamConnectionReceiverImpl(ExecutorService aExecutorService)
Instantiates a new prefetch input stream connection receiver impl.
|
| Modifier and Type | Method and Description |
|---|---|
boolean |
isOpenable(InputStream aInputStream)
Checks if is openable.
|
void |
open(InputStream aInputStream)
Open, see also
ConnectionOpenable.open(Object). |
closehasDatagram, pushDatagram, pushDatagrams, pushDatagrams, readDatagram, readDatagrams, releaseAllgetConnectionStatus, isClosable, isClosed, isOpenable, isOpened, open, setConnectionStatusclone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitreadDatagrams, readDatagramsreadDatagramhasDatagramclose, closeIn, closeQuietly, closeUncheckedpublic PrefetchInputStreamConnectionReceiverImpl()
public PrefetchInputStreamConnectionReceiverImpl(ExecutorService aExecutorService)
aExecutorService - the a executor servicepublic void open(InputStream aInputStream) throws org.refcodes.component.OpenException
AbstractPrefetchInputStreamReceiverConnectionOpenable.open(Object).open in interface org.refcodes.component.ConnectionOpenable<InputStream>open in class AbstractPrefetchInputStreamReceiver<DATA extends Serializable>aInputStream - the a input streamorg.refcodes.component.OpenException - the open exceptionpublic boolean isOpenable(InputStream aInputStream)
AbstractPrefetchInputStreamReceiverConnectionOpenable.ConnectionOpenAutomaton.isOpenable(Object).isOpenable in interface org.refcodes.component.ConnectionOpenable.ConnectionOpenAutomaton<InputStream>isOpenable in class AbstractPrefetchInputStreamReceiver<DATA extends Serializable>aInputStream - the a input streamCopyright © 2017. All rights reserved.