Module org.refcodes.io
Package org.refcodes.io
Class AbstractPrefetchInputStreamReceiver<DATA extends Serializable>
- java.lang.Object
-
- org.refcodes.component.AbstractConnectableAutomaton
-
- org.refcodes.io.AbstractDatagramsReceiver<DATA>
-
- org.refcodes.io.AbstractPrefetchInputStreamReceiver<DATA>
-
- Type Parameters:
DATA- The type of the datagram to be operated with.
- All Implemented Interfaces:
org.refcodes.component.Closable,org.refcodes.component.Closable.CloseAutomaton,org.refcodes.component.ClosedAccessor,org.refcodes.component.ConnectableComponent,org.refcodes.component.ConnectableComponent.ConnectableAutomaton,org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.OpenedAccessor,Availability,DatagramDestination<DATA>,DatagramReceiver<DATA>,DatagramsDestination<DATA>,DatagramsReceiver<DATA>,Receivable,org.refcodes.mixin.Loggable
- Direct Known Subclasses:
PrefetchBidirectionalStreamConnectionTransceiver,PrefetchInputStreamConnectionReceiver
public abstract class AbstractPrefetchInputStreamReceiver<DATA extends Serializable> extends AbstractDatagramsReceiver<DATA> implements org.refcodes.mixin.Loggable
Abstract implementation of theDatagramsReceiverinterface. As of the prefetching functionality, a separate daemon thread (retrieved via anExecutorService) reads from the providedInputStreamand places the datagrams into a datagram queue until the datagram queue's capacity is reached. If the queue is empty, then theAbstractDatagramsReceiver.receive()(AbstractDatagramsReceiver.receiveAll()) method is blocked until the daemon thread places new datagrams into the queue. See alsoAbstractDatagramsReceiver.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>
-
Nested classes/interfaces inherited from interface org.refcodes.component.ClosedAccessor
org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedProperty
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectableComponent
org.refcodes.component.ConnectableComponent.ConnectableAutomaton
-
-
Field Summary
-
Fields inherited from class org.refcodes.io.AbstractDatagramsReceiver
DATAGRAM_QUEUE_SIZE
-
-
Constructor Summary
Constructors Constructor Description AbstractPrefetchInputStreamReceiver()Creates anAbstractPrefetchInputStreamReceiver.AbstractPrefetchInputStreamReceiver(int aQueueCapacity)Creates anAbstractPrefetchInputStreamReceiverusing the given datagram queue capacity.AbstractPrefetchInputStreamReceiver(int aQueueCapacity, ExecutorService aExecutorService)Creates anAbstractPrefetchInputStreamReceiverusing the givenExecutorServicerequired for thread generation in an JEE environment.AbstractPrefetchInputStreamReceiver(ExecutorService aExecutorService)Creates anAbstractPrefetchInputStreamReceiverusing the givenExecutorServicerequired for thread generation in an JEE environment.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidclose()protected booleanisOpenable(InputStream aInputStream)Checks if is openable.protected voidopen(InputStream aInputStream)Open, see alsoConnectionOpenable.open(Object).-
Methods inherited from class org.refcodes.io.AbstractDatagramsReceiver
available, pushDatagram, pushDatagrams, pushDatagrams, receive, receiveAll
-
Methods inherited from class org.refcodes.component.AbstractConnectableAutomaton
getConnectionStatus, isClosable, isClosed, isOpenable, isOpened, open, setConnectionStatus
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.io.Availability
hasAvailable
-
Methods inherited from interface org.refcodes.component.Closable
closeIn, closeQuietly, closeUnchecked
-
Methods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpened
-
Methods inherited from interface org.refcodes.io.DatagramsDestination
receive
-
Methods inherited from interface org.refcodes.io.DatagramsReceiver
receive
-
-
-
-
Constructor Detail
-
AbstractPrefetchInputStreamReceiver
public AbstractPrefetchInputStreamReceiver()
Creates anAbstractPrefetchInputStreamReceiver.
-
AbstractPrefetchInputStreamReceiver
public AbstractPrefetchInputStreamReceiver(ExecutorService aExecutorService)
Creates anAbstractPrefetchInputStreamReceiverusing the givenExecutorServicerequired for thread generation in an JEE environment.- Parameters:
aExecutorService- TheExecutorServiceto be used, when null then anExecutorServicesomething lineExecutors.newCachedThreadPool()is then retrieved.
-
AbstractPrefetchInputStreamReceiver
public AbstractPrefetchInputStreamReceiver(int aQueueCapacity)
Creates anAbstractPrefetchInputStreamReceiverusing the given datagram queue capacity.- Parameters:
aQueueCapacity- The capacity of the prefetch queue before it blocks until data is read viaAbstractDatagramsReceiver.receive()(AbstractDatagramsReceiver.receiveAll()).
-
AbstractPrefetchInputStreamReceiver
public AbstractPrefetchInputStreamReceiver(int aQueueCapacity, ExecutorService aExecutorService)Creates anAbstractPrefetchInputStreamReceiverusing the givenExecutorServicerequired for thread generation in an JEE environment.- Parameters:
aQueueCapacity- The capacity of the prefetch queue before it blocks until data is read viaAbstractDatagramsReceiver.receive()(AbstractDatagramsReceiver.receiveAll()).aExecutorService- TheExecutorServiceto be used, when null then anExecutorServicesomething lineExecutors.newCachedThreadPool()is then retrieved.
-
-
Method Detail
-
close
public void close() throws IOException- Specified by:
closein interfaceorg.refcodes.component.Closable- Overrides:
closein classAbstractDatagramsReceiver<DATA extends Serializable>- Throws:
IOException
-
open
protected void open(InputStream aInputStream) throws IOException
Open, see alsoConnectionOpenable.open(Object).- Parameters:
aInputStream- the input stream- Throws:
IOException- the open exception
-
isOpenable
protected boolean isOpenable(InputStream aInputStream)
Checks if is openable. See alsoConnectionOpenable.ConnectionOpenAutomaton.isOpenable(Object).- Parameters:
aInputStream- the input stream- Returns:
- true, if is openable
-
-