Interface BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>

Type Parameters:
INPUT - The type of the input connection to be used.
OUTPUT - The type of the output connection to be used.
All Superinterfaces:
Availability, org.refcodes.component.BidirectionalConnectionComponent<INPUT,OUTPUT>, org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>, org.refcodes.component.BidirectionalConnectionOpenable<INPUT,OUTPUT>, org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,OUTPUT>, ByteDestination, ByteReceiver, BytesDestination, ByteSource, BytesReceiver, BytesSource, BytesTransceiver, BytesTransmitter, ByteTransceiver, ByteTransmitter, org.refcodes.component.Closable, org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.ClosedAccessor, org.refcodes.component.ConnectableComponent, org.refcodes.component.ConnectableComponent.ConnectableAutomaton, org.refcodes.component.ConnectionStatusAccessor, Flushable, org.refcodes.component.Flushable, org.refcodes.mixin.InputStreamAccessor, org.refcodes.component.OpenedAccessor, org.refcodes.mixin.OutputStreamAccessor, Receivable, Skippable, TimeoutInputStreamAccessor, Transmittable
All Known Subinterfaces:
BidirectionalStreamConnectionByteTransceiver
All Known Implementing Classes:
BidirectionalStreamConnectionByteTransceiverImpl, PrefetchBidirectionalStreamConnectionByteTransceiver

public interface BidirectionalConnectionByteTransceiver<INPUT,OUTPUT> extends BytesTransceiver, org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>
The BidirectionalConnectionByteTransceiver defines the DatagramTransceiver functionality set on top of a I/O connection (as of the BidirectionalConnectionComponent.BidirectionalConnectionAutomaton).