Module org.refcodes.io
Package org.refcodes.io
Interface BidirectionalConnectionTransceiver<DATA extends Serializable,INPUT,OUTPUT>
- Type Parameters:
DATA- The type of the datagram to be operated with.INPUT- The type of the input connection to be used.OUTPUT- The type of the output connection to be used.
- All Superinterfaces:
Availability,org.refcodes.component.BidirectionalConnectionComponent<INPUT,,OUTPUT> org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,,OUTPUT> org.refcodes.component.BidirectionalConnectionOpenable<INPUT,,OUTPUT> org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT,,OUTPUT> org.refcodes.component.Closable,org.refcodes.component.Closable.CloseAutomaton,org.refcodes.component.ClosedAccessor,org.refcodes.component.ConnectableComponent,org.refcodes.component.ConnectableComponent.ConnectableAutomaton,org.refcodes.component.ConnectionStatusAccessor,DatagramDestination<DATA>,DatagramReceiver<DATA>,DatagramsDestination<DATA>,DatagramSource<DATA>,DatagramsReceiver<DATA>,DatagramsSource<DATA>,DatagramsTransceiver<DATA>,DatagramsTransmitter<DATA>,DatagramTransceiver<DATA>,DatagramTransmitter<DATA>,Flushable,org.refcodes.component.Flushable,org.refcodes.component.OpenedAccessor,Receivable,Transmittable
- All Known Subinterfaces:
BidirectionalStreamConnectionTransceiver<DATA>
- All Known Implementing Classes:
BidirectionalStreamConnectionTransceiverImpl,PrefetchBidirectionalStreamConnectionTransceiver
public interface BidirectionalConnectionTransceiver<DATA extends Serializable,INPUT,OUTPUT>
extends DatagramsTransceiver<DATA>, org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT,OUTPUT>
The
BidirectionalConnectionTransceiver defines the
DatagramTransceiver functionality set on top of a I/O connection (as
of the BidirectionalConnectionComponent.BidirectionalConnectionAutomaton).-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.component.BidirectionalConnectionComponent
org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT extends Object,OUTPUT extends Object> Nested classes/interfaces inherited from interface org.refcodes.component.BidirectionalConnectionOpenable
org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT extends Object,OUTPUT extends Object> Nested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.ClosedAccessor
org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedPropertyNested classes/interfaces inherited from interface org.refcodes.component.ConnectableComponent
org.refcodes.component.ConnectableComponent.ConnectableAutomatonNested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.Flushable
org.refcodes.component.Flushable.FlushBuilder<B extends org.refcodes.component.Flushable.FlushBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
org.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedProperty -
Method Summary
Methods inherited from interface org.refcodes.io.Availability
available, hasAvailableMethods inherited from interface org.refcodes.component.BidirectionalConnectionOpenable
openMethods inherited from interface org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton
isOpenableMethods inherited from interface org.refcodes.component.Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface org.refcodes.component.Closable.CloseAutomaton
isClosableMethods inherited from interface org.refcodes.component.ClosedAccessor
isClosedMethods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpenedMethods inherited from interface org.refcodes.io.DatagramsDestination
receive, receiveMethods inherited from interface org.refcodes.io.DatagramsReceiver
receive, receiveAllMethods inherited from interface org.refcodes.io.DatagramsSource
transmit, transmitAllMethods inherited from interface org.refcodes.io.DatagramsTransmitter
transmitMethods inherited from interface org.refcodes.io.DatagramTransmitter
flushMethods inherited from interface org.refcodes.component.Flushable
flushUnchecked, isFlushable