Module org.refcodes.io
Package org.refcodes.io
Class BidirectionalStreamConnectionTransceiverImpl<DATA extends Serializable>
- java.lang.Object
-
- org.refcodes.component.AbstractConnectableAutomaton
-
- org.refcodes.io.AbstractInputStreamReceiver<DATA>
-
- org.refcodes.io.BidirectionalStreamConnectionTransceiverImpl<DATA>
-
- Type Parameters:
DATA- the generic type
- All Implemented Interfaces:
Flushable,org.refcodes.component.BidirectionalConnectionComponent<InputStream,OutputStream>,org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<InputStream,OutputStream>,org.refcodes.component.BidirectionalConnectionOpenable<InputStream,OutputStream>,org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<InputStream,OutputStream>,org.refcodes.component.Closable,org.refcodes.component.Closable.CloseAutomaton,org.refcodes.component.ClosedAccessor,org.refcodes.component.ConnectableComponent,org.refcodes.component.ConnectableComponent.ConnectableAutomaton,org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.Flushable,org.refcodes.component.OpenedAccessor,Availability,BidirectionalConnectionTransceiver<DATA,InputStream,OutputStream>,BidirectionalStreamConnectionTransceiver<DATA>,DatagramDestination<DATA>,DatagramReceiver<DATA>,DatagramsDestination<DATA>,DatagramSource<DATA>,DatagramsReceiver<DATA>,DatagramsSource<DATA>,DatagramsTransceiver<DATA>,DatagramsTransmitter<DATA>,DatagramTransceiver<DATA>,DatagramTransmitter<DATA>,Receivable,Transmittable
public class BidirectionalStreamConnectionTransceiverImpl<DATA extends Serializable> extends AbstractInputStreamReceiver<DATA> implements BidirectionalStreamConnectionTransceiver<DATA>
The Class BidirectionalStreamConnectionTransceiverImpl.- Author:
- steiner
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.BidirectionalConnectionComponent
org.refcodes.component.BidirectionalConnectionComponent.BidirectionalConnectionAutomaton<INPUT extends Object,OUTPUT extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.component.BidirectionalConnectionOpenable
org.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<INPUT extends Object,OUTPUT extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>
-
Nested classes/interfaces inherited from interface org.refcodes.component.ClosedAccessor
org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedProperty
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectableComponent
org.refcodes.component.ConnectableComponent.ConnectableAutomaton
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusProperty
-
-
Constructor Summary
Constructors Constructor Description BidirectionalStreamConnectionTransceiverImpl()Instantiates a new bidirectional stream connection transceiver impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidclose()voidflush()booleanisOpenable(InputStream aInputStream, OutputStream aOutputStream)voidopen(InputStream aInputStream, OutputStream aOutputStream)protected voidopen(OutputStream aOutputStream)HINT: For testing purposes you can pass an already flushedObjectOutputStream(viaObjectOutputStream.flush()) encapsulating aPipedOutputStreamwhich in turn encapsulates aPipedInputStreamto thisopen(OutputStream)method.voidtransmit(DATA aDatagram)Writes (sends) a datagram to a listeningDatagramReceiver.-
Methods inherited from class org.refcodes.io.AbstractInputStreamReceiver
available, isOpenable, open, receive
-
Methods inherited from class org.refcodes.component.AbstractConnectableAutomaton
getConnectionStatus, isClosable, isClosed, isOpenable, isOpened, open, setConnectionStatus
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.io.Availability
available, hasAvailable
-
Methods inherited from interface org.refcodes.component.Closable
closeIn, closeQuietly, closeUnchecked
-
Methods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpened
-
Methods inherited from interface org.refcodes.io.DatagramsDestination
receive, receive
-
Methods inherited from interface org.refcodes.io.DatagramsReceiver
receive, receiveAll
-
Methods inherited from interface org.refcodes.io.DatagramsSource
transmitAll
-
Methods inherited from interface org.refcodes.io.DatagramsTransmitter
transmit
-
-
-
-
Method Detail
-
isOpenable
public boolean isOpenable(InputStream aInputStream, OutputStream aOutputStream)
- Specified by:
isOpenablein interfaceorg.refcodes.component.BidirectionalConnectionOpenable.BidirectionalConnectionOpenAutomaton<InputStream,OutputStream>
-
open
public void open(InputStream aInputStream, OutputStream aOutputStream) throws IOException
- Specified by:
openin interfaceorg.refcodes.component.BidirectionalConnectionOpenable<InputStream,OutputStream>- Throws:
IOException
-
transmit
public void transmit(DATA aDatagram) throws IOException
Writes (sends) a datagram to a listeningDatagramReceiver.- Specified by:
transmitin interfaceDatagramSource<DATA extends Serializable>- Specified by:
transmitin interfaceDatagramsSource<DATA extends Serializable>- Parameters:
aDatagram- The datagram to be pushed to the receivingDatagramSource.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
flush
public void flush() throws IOException- Specified by:
flushin interfaceDatagramTransmitter<DATA extends Serializable>- Specified by:
flushin interfaceFlushable- Specified by:
flushin interfaceorg.refcodes.component.Flushable- Throws:
IOException
-
close
public void close() throws IOException- Specified by:
closein interfaceorg.refcodes.component.Closable- Overrides:
closein classAbstractInputStreamReceiver<DATA extends Serializable>- Throws:
IOException
-
open
protected void open(OutputStream aOutputStream) throws IOException
HINT: For testing purposes you can pass an already flushedObjectOutputStream(viaObjectOutputStream.flush()) encapsulating aPipedOutputStreamwhich in turn encapsulates aPipedInputStreamto thisopen(OutputStream)method. This enables you a non-blocking test of theOutputStreamConnectionDatagramsTransmitterconnected with theInputStreamConnectionReceiverImplcounterpart which is being opened with thePipedInputStream. ATTENTION: For maintainers, please keep the below code in sync with the code fromOutputStreamConnectionDatagramsTransmitter.open(java.io.OutputStream); except do not set the connection status here, make it protected and do not @Override anything.- Parameters:
aOutputStream- the output stream- Throws:
IOException- the open exception
-
-