java.lang.Object
org.refcodes.io.ByteArraySource
- All Implemented Interfaces:
ByteSource,BytesSource,org.refcodes.struct.ByteArrayAccessor
public class ByteArraySource
extends Object
implements BytesSource, org.refcodes.struct.ByteArrayAccessor
The Class ByteArraySource.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.struct.ByteArrayAccessor
org.refcodes.struct.ByteArrayAccessor.ByteArrayBuilder<B extends org.refcodes.struct.ByteArrayAccessor.ByteArrayBuilder<B>>, org.refcodes.struct.ByteArrayAccessor.ByteArrayMutator, org.refcodes.struct.ByteArrayAccessor.ByteArrayProperty -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbyte[]getBytes()voidtransmitByte(byte aByte) Writes (sends) a byte.voidtransmitBytes(byte[] aBytes, int aOffset, int aLength) Writes (sends) a byte block.Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.io.BytesSource
transmitAllBytes
-
Constructor Details
-
ByteArraySource
public ByteArraySource()
-
-
Method Details
-
transmitByte
Writes (sends) a byte.- Specified by:
transmitBytein interfaceByteSource- Specified by:
transmitBytein interfaceBytesSource- Parameters:
aByte- The byte to be pushed.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
transmitBytes
Writes (sends) a byte block.- Specified by:
transmitBytesin interfaceBytesSource- Parameters:
aBytes- The byte to be pushed.aOffset- The offset from which to take the data.aLength- The number of elements to push starting at the given offset.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
getBytes
public byte[] getBytes()- Specified by:
getBytesin interfaceorg.refcodes.struct.ByteArrayAccessor
-