Interface ByteDestination

    • Method Summary

      All Methods Instance Methods Abstract Methods 
      Modifier and Type Method Description
      byte receiveByte()
      Reads (receives) the next byte, in case none byte is available, then this method blocks until one is available.
    • Method Detail

      • receiveByte

        byte receiveByte()
                  throws IOException,
                         EOFException
        Reads (receives) the next byte, in case none byte is available, then this method blocks until one is available.
        Returns:
        The next byte available .
        Throws:
        IOException - Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
        EOFException - Signals that an end of file or end of stream has been reached unexpectedly during input.