-
- All Known Subinterfaces:
BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>,BidirectionalStreamConnectionByteTransceiver,ByteReceiver,BytesDestination,BytesReceiver,BytesTransceiver,ByteTransceiver,ConnectionBytesReceiver<CON>,ConnectionBytesTransceiver<CON>,InputStreamConnectionByteReceiver
- All Known Implementing Classes:
AbstractBytesDestination,AbstractBytesReceiver,AbstractInputStreamByteReceiver,AbstractPrefetchInputStreamByteReceiver,BidirectionalStreamByteTransceiver,BidirectionalStreamConnectionByteTransceiverImpl,ByteArrayReceiver,BytesReceiverDecorator,InputStreamByteReceiver,InputStreamConnectionByteReceiverImpl,LoopbackBytesReceiver,LoopbackBytesTransceiver,PrefetchBidirectionalStreamByteTransceiver,PrefetchBidirectionalStreamConnectionByteTransceiver,PrefetchInputStreamByteReceiver,PrefetchInputStreamConnectionByteReceiver
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface ByteDestination
TheByteDestinationis used to receive bytes in a unified way. ThereceiveByte()method provides the next available byte from the counterpartDatagramTransmitter; in case there is none available, then this method halts until one is available.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description bytereceiveByte()Reads (receives) the next byte, in case none byte is available, then this method blocks until one is available.
-
-
-
Method Detail
-
receiveByte
byte receiveByte() throws IOException, EOFExceptionReads (receives) the next byte, in case none byte is available, then this method blocks until one is available.- Returns:
- The next byte available .
- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.EOFException- Signals that an end of file or end of stream has been reached unexpectedly during input.
-
-