- All Superinterfaces:
Availability,ByteDestination,org.refcodes.component.Closable,org.refcodes.component.Closable.CloseAutomaton,org.refcodes.component.ClosedAccessor,org.refcodes.component.ConnectableComponent,org.refcodes.component.ConnectableComponent.ConnectableAutomaton,org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.OpenedAccessor,Receivable
- All Known Subinterfaces:
BidirectionalConnectionByteTransceiver<INPUT,,OUTPUT> BidirectionalStreamConnectionByteTransceiver,BytesReceiver,BytesTransceiver,ByteTransceiver,ConnectionBytesReceiver<CON>,ConnectionBytesTransceiver<CON>,InputStreamConnectionByteReceiver
- All Known Implementing Classes:
AbstractBytesReceiver,AbstractInputStreamByteReceiver,AbstractPrefetchInputStreamByteReceiver,BidirectionalStreamByteTransceiver,BidirectionalStreamConnectionByteTransceiverImpl,ByteArrayReceiver,BytesReceiverDecorator,InputStreamByteReceiver,InputStreamConnectionByteReceiverImpl,LoopbackBytesReceiver,LoopbackBytesTransceiver,PrefetchBidirectionalStreamByteTransceiver,PrefetchBidirectionalStreamConnectionByteTransceiver,PrefetchInputStreamByteReceiver,PrefetchInputStreamConnectionByteReceiver
The
ByteReceiver is used to receive bytes in a unified way. The
ByteDestination.receiveByte() method provides the next available datagram from the
counterpart DatagramTransmitter; in case there is none available,
then this method halts until one is available or the ByteReceiver is
being shut down or the underlying connection is closed. The
Availability.available() method returns true in case a next datagram can be
fetched via the ByteDestination.receiveByte() method from the ByteReceiver
counterpart.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>Nested classes/interfaces inherited from interface org.refcodes.component.ClosedAccessor
org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedPropertyNested classes/interfaces inherited from interface org.refcodes.component.ConnectableComponent
org.refcodes.component.ConnectableComponent.ConnectableAutomatonNested classes/interfaces inherited from interface org.refcodes.component.ConnectionStatusAccessor
org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusMutator, org.refcodes.component.ConnectionStatusAccessor.ConnectionStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.OpenedAccessor
org.refcodes.component.OpenedAccessor.OpenedMutator, org.refcodes.component.OpenedAccessor.OpenedProperty -
Method Summary
Methods inherited from interface org.refcodes.io.Availability
available, hasAvailableMethods inherited from interface org.refcodes.io.ByteDestination
receiveByteMethods inherited from interface org.refcodes.component.Closable
close, closeIn, closeQuietly, closeUncheckedMethods inherited from interface org.refcodes.component.Closable.CloseAutomaton
isClosableMethods inherited from interface org.refcodes.component.ClosedAccessor
isClosedMethods inherited from interface org.refcodes.component.ConnectionStatusAccessor
getConnectionStatus, isOpened