-
- All Superinterfaces:
Availability,ByteDestination,org.refcodes.component.Closable,org.refcodes.component.Closable.CloseAutomaton,org.refcodes.component.ClosedAccessor,org.refcodes.component.ConnectableComponent,org.refcodes.component.ConnectableComponent.ConnectableAutomaton,org.refcodes.component.ConnectionStatusAccessor,org.refcodes.component.OpenedAccessor,Receivable
- All Known Subinterfaces:
BidirectionalConnectionByteTransceiver<INPUT,OUTPUT>,BidirectionalStreamConnectionByteTransceiver,BytesReceiver,BytesTransceiver,ByteTransceiver,ConnectionBytesReceiver<CON>,ConnectionBytesTransceiver<CON>,InputStreamConnectionByteReceiver
- All Known Implementing Classes:
AbstractBytesReceiver,AbstractInputStreamByteReceiver,AbstractPrefetchInputStreamByteReceiver,BidirectionalStreamByteTransceiver,BidirectionalStreamConnectionByteTransceiverImpl,ByteArrayReceiver,BytesReceiverDecorator,InputStreamByteReceiver,InputStreamConnectionByteReceiverImpl,LoopbackBytesReceiver,LoopbackBytesTransceiver,PrefetchBidirectionalStreamByteTransceiver,PrefetchBidirectionalStreamConnectionByteTransceiver,PrefetchInputStreamByteReceiver,PrefetchInputStreamConnectionByteReceiver
public interface ByteReceiver extends ByteDestination, Receivable
TheByteReceiveris used to receive bytes in a unified way. TheByteDestination.receiveByte()method provides the next available datagram from the counterpartDatagramTransmitter; in case there is none available, then this method halts until one is available or theByteReceiveris being shut down or the underlying connection is closed. TheAvailability.available()method returns true in case a next datagram can be fetched via theByteDestination.receiveByte()method from theByteReceivercounterpart.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.Closable
org.refcodes.component.Closable.CloseAutomaton, org.refcodes.component.Closable.CloseBuilder<B extends org.refcodes.component.Closable.CloseBuilder<B>>
-
Nested classes/interfaces inherited from interface org.refcodes.component.ClosedAccessor
org.refcodes.component.ClosedAccessor.ClosedMutator, org.refcodes.component.ClosedAccessor.ClosedProperty
-
Nested classes/interfaces inherited from interface org.refcodes.component.ConnectableComponent
org.refcodes.component.ConnectableComponent.ConnectableAutomaton
-
-
Method Summary
-
Methods inherited from interface org.refcodes.io.Availability
available, hasAvailable
-
Methods inherited from interface org.refcodes.io.ByteDestination
receiveByte
-
-