Interface BytesSource

    • Method Detail

      • transmitByte

        default void transmitByte​(byte aByte)
                           throws IOException
        Writes (sends) a byte.
        Specified by:
        transmitByte in interface ByteSource
        Parameters:
        aByte - The byte to be pushed.
        Throws:
        IOException - Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
      • transmitAllBytes

        default void transmitAllBytes​(byte[] aBytes)
                               throws IOException
        Writes (sends) a byte block.
        Parameters:
        aBytes - The byte to be pushed.
        Throws:
        IOException - Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
      • transmitBytes

        void transmitBytes​(byte[] aBytes,
                           int aOffset,
                           int aLength)
                    throws IOException
        Writes (sends) a byte block.
        Parameters:
        aBytes - The byte to be pushed.
        aOffset - The offset from which to take the data.
        aLength - The number of elements to push starting at the given offset.
        Throws:
        IOException - Thrown in case opening or accessing an open line (connection, junction, link) caused problems.