java.lang.Object
org.refcodes.io.ShortArraySource
- All Implemented Interfaces:
ShortSource,ShortsSource,org.refcodes.struct.ShortArrayAccessor
public class ShortArraySource
extends Object
implements ShortsSource, org.refcodes.struct.ShortArrayAccessor
The Class ShortArraySource.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.struct.ShortArrayAccessor
org.refcodes.struct.ShortArrayAccessor.ShortArrayBuilder<B extends org.refcodes.struct.ShortArrayAccessor.ShortArrayBuilder<B>>, org.refcodes.struct.ShortArrayAccessor.ShortArrayMutator, org.refcodes.struct.ShortArrayAccessor.ShortArrayProperty -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionshort[]voidtransmitShort(short aShort) Writes (sends) a short.voidtransmitShorts(short[] aShorts, int aOffset, int aLength) Writes (sends) a short block.Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.io.ShortsSource
transmitShorts
-
Constructor Details
-
ShortArraySource
public ShortArraySource()
-
-
Method Details
-
transmitShort
Writes (sends) a short.- Specified by:
transmitShortin interfaceShortSource- Specified by:
transmitShortin interfaceShortsSource- Parameters:
aShort- The short to be pushed.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
transmitShorts
Writes (sends) a short block.- Specified by:
transmitShortsin interfaceShortsSource- Parameters:
aShorts- The short to be pushed.aOffset- The offset from which to take the data.aLength- The number of elements to push starting at the given offset.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
getShorts
public short[] getShorts()- Specified by:
getShortsin interfaceorg.refcodes.struct.ShortArrayAccessor
-