-
- All Known Subinterfaces:
ConnectionShortsTransceiver<CON>,ConnectionShortsTransmitter<CON>,ShortsSource,ShortsTransceiver,ShortsTransmitter,ShortTransceiver,ShortTransmitter
- All Known Implementing Classes:
AbstractShortsTransmitter,LoopbackShortsTransceiver,LoopbackShortsTransmitter,OutputStreamConnectionShortsTransmitter,OutputStreamShortsTransmitter,ShortArraySource,ShortTransmitterDecorator
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface ShortSource
TheShortSourceis used to send shorts in a unified way.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidtransmitShort(short aShort)Writes (sends) a short.
-
-
-
Method Detail
-
transmitShort
void transmitShort(short aShort) throws IOExceptionWrites (sends) a short.- Parameters:
aShort- The short to be pushed.- Throws:
IOException- Thrown in case opening or accessing an open line (connection, junction, link) caused problems.
-
-