Interface TimeoutInputStreamAccessor

  • Method Details

    • getInputStream

      TimeoutInputStream getInputStream(long aTimeoutMillis)
      Retrieves the timeout input stream from the timeout input stream property.
      Parameters:
      aTimeoutMillis - The default timeout for read operations not explicitly called with a timeout argument. With a value of -1 timeout handling is disabled (blocking mode).
      Returns:
      The timeout input stream stored by the timeout input stream property.