- All Superinterfaces:
org.refcodes.mixin.InputStreamAccessor
- All Known Subinterfaces:
BidirectionalConnectionByteTransceiver<INPUT,,OUTPUT> BidirectionalStreamConnectionByteTransceiver,BytesReceiver,BytesTransceiver,ConnectionBytesReceiver<CON>,ConnectionBytesTransceiver<CON>,InputStreamConnectionByteReceiver,TimeoutInputStreamAccessor.TimeoutInputStreamProperty
- All Known Implementing Classes:
AbstractBytesReceiver,AbstractInputStreamByteReceiver,AbstractPrefetchInputStreamByteReceiver,BidirectionalStreamByteTransceiver,BidirectionalStreamConnectionByteTransceiverImpl,ByteArrayReceiver,BytesReceiverDecorator,InputStreamByteReceiver,InputStreamConnectionByteReceiverImpl,LoopbackBytesReceiver,LoopbackBytesTransceiver,PrefetchBidirectionalStreamByteTransceiver,PrefetchBidirectionalStreamConnectionByteTransceiver,PrefetchInputStreamByteReceiver,PrefetchInputStreamConnectionByteReceiver
public interface TimeoutInputStreamAccessor
extends org.refcodes.mixin.InputStreamAccessor
Provides an accessor for an timeout input stream property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceTimeoutInputStreamAccessor.TimeoutInputStreamBuilder<B extends TimeoutInputStreamAccessor.TimeoutInputStreamBuilder<?>>Provides a mutator for an timeout input stream property.static interfaceProvides a mutator for an timeout input stream property.static interfaceProvides an timeout input stream property.Nested classes/interfaces inherited from interface org.refcodes.mixin.InputStreamAccessor
org.refcodes.mixin.InputStreamAccessor.InputStreamBuilder<B extends org.refcodes.mixin.InputStreamAccessor.InputStreamBuilder<?>>, org.refcodes.mixin.InputStreamAccessor.InputStreamMutator, org.refcodes.mixin.InputStreamAccessor.InputStreamProperty -
Method Summary
Modifier and TypeMethodDescriptiongetInputStream(long aTimeoutMillis) Retrieves the timeout input stream from the timeout input stream property.Methods inherited from interface org.refcodes.mixin.InputStreamAccessor
getInputStream
-
Method Details
-
getInputStream
Retrieves the timeout input stream from the timeout input stream property.- Parameters:
aTimeoutMillis- The default timeout for read operations not explicitly called with a timeout argument. With a value of -1 timeout handling is disabled (blocking mode).- Returns:
- The timeout input stream stored by the timeout input stream property.
-