Uses of Class
org.refcodes.io.AbstractBytesDestination
-
-
Uses of AbstractBytesDestination in org.refcodes.io
Subclasses of AbstractBytesDestination in org.refcodes.io Modifier and Type Class Description classAbstractBytesReceiverTheAbstractBytesReceiveris a base abstract implementation of theBytesReceiverinterface providing common functionality for concrete real live implementations.classAbstractPrefetchInputStreamByteReceiverAbstract implementation of theBytesReceiverinterface.classByteArrayReceiverThe Class ByteArrayReceiver.classBytesReceiverDecoratorTheBytesReceiverDecoratordecorates aBytesDestinationwith the additional methods of aBytesReceivermaking it easy to use aBytesDestinationwherever aBytesReceiveris expected.classLoopbackBytesReceiverALoopbackBytesReceiveris aDatagramReceiverconnected directly within the same JVM with aLoopbackBytesTransmitter; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classLoopbackBytesTransceiverALoopbackBytesTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackBytesTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classPrefetchBidirectionalStreamConnectionByteTransceiverThe Class PrefetchBidirectionalStreamConnectionByteTransceiver.classPrefetchInputStreamConnectionByteReceiverImplementation of theInputStreamConnectionReceiverinterface.
-