Uses of Interface
org.refcodes.io.ByteDestination
-
-
Uses of ByteDestination in org.refcodes.io
Subinterfaces of ByteDestination in org.refcodes.io Modifier and Type Interface Description interfaceBidirectionalConnectionByteTransceiver<INPUT,OUTPUT>TheBidirectionalConnectionByteTransceiverdefines theDatagramTransceiverfunctionality set on top of a I/O connection (as of theBidirectionalConnectionComponent.BidirectionalConnectionAutomaton).interfaceBidirectionalStreamConnectionByteTransceiverABidirectionalStreamConnectionByteTransceiveris aDatagramTransceiverconnected through I/O streams with anotherBidirectionalStreamConnectionByteTransceiver.interfaceByteReceiverTheByteReceiveris used to receive bytes in a unified way.interfaceBytesDestinationTheBytesDestinationis used to receive byte blocks (arrays) in a unified way.interfaceBytesReceiverThe Interface BytesReceiver.interfaceBytesTransceiverABytesTransceivercombines the functionality of aBytesTransmitterand of aBytesReceiver. e.g. for building loopback devices.interfaceByteTransceiverCombines theByteTransmitterandByteReceiverfunctionality in a single interface to be implemented by a single class so thatByteTransmitterandByteReceiverfunctionality can be provided by a single instance.interfaceConnectionBytesReceiver<CON>TheConnectionBytesReceiverdefines theDatagramReceiverfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "byte".interfaceConnectionBytesTransceiver<CON>TheConnectionBytesTransceiverdefines theDatagramTransceiverfunctionality set on top of a connection (as of theConnectionComponent.ConnectionAutomaton) for data types "byte".interfaceInputStreamConnectionByteReceiverAInputStreamConnectionByteReceiveris aDatagramReceiverconnected through I/O streams with aOutputStreamConnectionDatagramsTransmitter.Classes in org.refcodes.io that implement ByteDestination Modifier and Type Class Description classAbstractBytesDestinationTheAbstractBytesDestinationis a base abstract implementation of theBytesDestinationinterface providing common functionality for concrete real implementations.classAbstractBytesReceiverTheAbstractBytesReceiveris a base abstract implementation of theBytesReceiverinterface providing common functionality for concrete real live implementations.classAbstractInputStreamByteReceiverAbstract implementation of theBytesReceiverinterface.classAbstractPrefetchInputStreamByteReceiverAbstract implementation of theBytesReceiverinterface.classBidirectionalStreamByteTransceiverThe Class BidirectionalStreamByteTransceiver.classBidirectionalStreamConnectionByteTransceiverImplThe Class BidirectionalStreamConnectionByteTransceiverImpl.classByteArrayReceiverThe Class ByteArrayReceiver.classBytesReceiverDecoratorTheBytesReceiverDecoratordecorates aBytesDestinationwith the additional methods of aBytesReceivermaking it easy to use aBytesDestinationwherever aBytesReceiveris expected.classInputStreamByteReceiverThe Class InputStreamByteReceiver.classInputStreamConnectionByteReceiverImplImplementation of theInputStreamConnectionReceiverinterface.classLoopbackBytesReceiverALoopbackBytesReceiveris aDatagramReceiverconnected directly within the same JVM with aLoopbackBytesTransmitter; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classLoopbackBytesTransceiverALoopbackBytesTransceiveris aDatagramTransceiverconnected directly within the same JVM with anotherLoopbackBytesTransceiver; a "loopback" connection is used for establishing the connection which cannot be accessed outside the JVM or the running machine.classPrefetchBidirectionalStreamByteTransceiverThe Class PrefetchBidirectionalStreamByteTransceiver.classPrefetchBidirectionalStreamConnectionByteTransceiverThe Class PrefetchBidirectionalStreamConnectionByteTransceiver.classPrefetchInputStreamByteReceiverThe Class PrefetchInputStreamByteReceiver.classPrefetchInputStreamConnectionByteReceiverImplementation of theInputStreamConnectionReceiverinterface.
-