Uses of Class
org.refcodes.io.TimeoutInputStream
-
-
Uses of TimeoutInputStream in org.refcodes.io
Subclasses of TimeoutInputStream in org.refcodes.io Modifier and Type Class Description static classTimeoutInputStream.DummyTimeoutInputStreamDummy implementation of aTimeoutInputStreamdirectly delegating to the givenInputStreamto test whether theTimeoutInputStreamhas any latencies compared to theTimeoutInputStream.DummyTimeoutInputStream.Methods in org.refcodes.io that return TimeoutInputStream Modifier and Type Method Description default TimeoutInputStreamBytesReceiver. getInputStream(long aTimeoutInMs)Retrieves theInputStreamas provided byBytesReceiver.getInputStream()wrapped in aTimeoutInputStreamor an implementation depended implementation of aTimeoutInputStream.TimeoutInputStreamTimeoutInputStreamAccessor. getInputStream(long aTimeoutInMs)Retrieves the timeout input stream from the timeout input stream property.default TimeoutInputStreamTimeoutInputStreamAccessor.TimeoutInputStreamProperty. letTimeoutInputStream(TimeoutInputStream aTimeoutInputStream)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTimeoutInputStream(setter) as ofTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)and returns the very same value (getter).Methods in org.refcodes.io with parameters of type TimeoutInputStream Modifier and Type Method Description default TimeoutInputStreamTimeoutInputStreamAccessor.TimeoutInputStreamProperty. letTimeoutInputStream(TimeoutInputStream aTimeoutInputStream)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenTimeoutInputStream(setter) as ofTimeoutInputStreamAccessor.TimeoutInputStreamMutator.setInputStream(TimeoutInputStream)and returns the very same value (getter).voidTimeoutInputStreamAccessor.TimeoutInputStreamMutator. setInputStream(TimeoutInputStream aTimeoutInputStream)Sets the timeout input stream for the timeout input stream property.BTimeoutInputStreamAccessor.TimeoutInputStreamBuilder. withInputStream(TimeoutInputStream aTimeoutInputStream)Sets the timeout input stream to use and returns this builder as of the Builder-Pattern.
-